@@ -312,7 +312,8 @@ KexiTabbedToolBar::Private::Private(KexiTabbedToolBar *t)
 //! @return true if @a style name is specific regarding tab styling
 static bool isSpecificTabStyle(const QString &styleName)
 {
-    return styleName == "oxygen" || styleName == "qtcurve" || styleName == "gtk+";
+    return styleName == "oxygen" || styleName == "qtcurve" || styleName == "gtk+"
+           || styleName == "gtk2";
 }
 
 KexiTabbedToolBarStyle::KexiTabbedToolBarStyle(const QString &baseStyleName)
@@ -330,8 +331,8 @@ void KexiTabbedToolBarStyle::drawControl(ControlElement element, const QStyleOpt
     const QString styleName(baseStyle()->objectName());
     qreal origOpacity = -1.0;
     if (element == CE_TabBarTab) {
-        const QStyleOptionTabV3* opt
-            = qstyleoption_cast<const QStyleOptionTabV3*>(option);
+        const QStyleOptionTab* opt
+            = qstyleoption_cast<const QStyleOptionTab*>(option);
         const QTabBar* tabBar = qobject_cast<const QTabBar*>(widget);
         KexiTabbedToolBar* tbar = tabBar
             ? qobject_cast<KexiTabbedToolBar*>(tabBar->parentWidget()) : 0;
@@ -348,7 +349,7 @@ void KexiTabbedToolBarStyle::drawControl(ControlElement element, const QStyleOpt
                 }
             }
 
-            QStyleOptionTabV3 newOpt(*opt);
+            QStyleOptionTab newOpt(*opt);
             const bool specificStyle = isSpecificTabStyle(styleName);
             newOpt.text = (specificStyle ? " " : "")
                     + tabBar->tabText(index)
@@ -375,7 +376,11 @@ void KexiTabbedToolBarStyle::drawControl(ControlElement element, const QStyleOpt
                     }
                 }
                 else {
-                    bg = Qt::transparent;
+                    if (styleName == "fusion") {
+                        bg = newOpt.palette.brush(QPalette::Active, QPalette::Button);
+                    } else {
+                        bg = Qt::transparent;
+                    }
                 }
                 QFont origFont(painter->font());
                 QFont f(origFont);
@@ -489,7 +494,7 @@ QSize KexiTabbedToolBarTabBar::tabSizeHint(int index) const
     ot.initFrom(this);
     QFont f(font());
     f.setBold(true);
-    ot.text = (isSpecificTabStyle(style()->objectName()) ? "  " : "") + tabText(index);
+    ot.text = (isSpecificTabStyle(customStyle->baseStyle()->objectName()) ? "  " : "") + tabText(index);
     ot.fontMetrics = QFontMetrics(f);
     int w = customStyle->pixelMetric(QStyle::PM_TabBarTabHSpace, &ot, this);
     if (w <= 0) { // needed e.g. for oxygen
@@ -1239,12 +1244,12 @@ KexiMainWindow::Private::Private(KexiMainWindow* w)
     propEditorDockWidget = 0;
     navDockWidget = 0;
     propEditorTabWidget = 0;
-    KexiProjectData *pdata = Kexi::startupHandler().projectData();
-    userMode = Kexi::startupHandler().forcedUserMode() /* <-- simply forced the user mode */
+    KexiProjectData *pdata = KexiStartupHandler::global()->projectData();
+    userMode = KexiStartupHandler::global()->forcedUserMode() /* <-- simply forced the user mode */
                /* project has 'user mode' set as default and not 'design mode' override is found: */
-               || (pdata && pdata->userMode() && !Kexi::startupHandler().forcedDesignMode());
-    isProjectNavigatorVisible = Kexi::startupHandler().isProjectNavigatorVisible();
-    isMainMenuVisible = Kexi::startupHandler().isMainMenuVisible();
+               || (pdata && pdata->userMode() && !KexiStartupHandler::global()->forcedDesignMode());
+    isProjectNavigatorVisible = KexiStartupHandler::global()->isProjectNavigatorVisible();
+    isMainMenuVisible = KexiStartupHandler::global()->isMainMenuVisible();
     navigator = 0;
     prj = 0;
     config = KSharedConfig::openConfig();
