@@ -18,6 +18,7 @@
 */
 
 #include "importtablewizard.h"
+#include "importoptionsdlg.h"
 #include "migratemanager.h"
 #include "keximigrate.h"
 #include "keximigratedata.h"
@@ -37,7 +38,6 @@
 #include <widget/KexiConnectionSelectorWidget.h>
 #include <widget/KexiProjectSelectorWidget.h>
 #include <widget/KexiDBTitlePage.h>
-#include <widget/KexiFileWidget.h>
 #include <widget/KexiNameWidget.h>
 
 #include <KDbConnectionData>
@@ -45,6 +45,7 @@
 #include <KDbDriverManager>
 #include <KDbDriverManager>
 #include <KDbSqlResult>
+#include <KDbTransactionGuard>
 #include <KDbUtils>
 
 #include <KMessageBox>
@@ -73,6 +74,7 @@ ImportTableWizard::ImportTableWizard ( KDbConnection* curDB, QWidget* parent, QM
     m_prjSet = 0;
     m_importComplete = false;
     m_importWasCanceled = false;
+    m_sourceDbEncoding = QString::fromLatin1(KexiUtils::encoding()); //default
 
     KexiMainWindowIface::global()->setReasonableDialogSize(this);
 
@@ -172,22 +174,20 @@ void ImportTableWizard::setupSrcConn()
 {
     m_srcConnPageWidget = new QWidget(this);
     QVBoxLayout *vbox = new QVBoxLayout(m_srcConnPageWidget);
-    KexiUtils::setStandardMarginsAndSpacing(vbox);
 
     m_srcConnSel = new KexiConnectionSelectorWidget(&Kexi::connset(),
-                                           "kfiledialog:///ProjectMigrationSourceDir",
-                                           KFileWidget::Opening, m_srcConnPageWidget);
+                            QUrl("kfiledialog:///ProjectMigrationSourceDir"),
+                            KexiConnectionSelectorWidget::Opening, m_srcConnPageWidget);
 
     m_srcConnSel->hideConnectonIcon();
-    m_srcConnSel->showSimpleConn();
+    m_srcConnSel->showSimpleConnection();
 
-    QSet<QString> excludedFilters;
     //! @todo remove when support for kexi files as source prj is added in migration
-    excludedFilters
-        << KDb::defaultFileBasedDriverMimeType()
-        << "application/x-kexiproject-shortcut"
-        << "application/x-kexi-connectiondata";
-    m_srcConnSel->fileWidget->setExcludedFilters(excludedFilters);
+    const QStringList excludedMimeTypes({
+        KDb::defaultFileBasedDriverMimeType(),
+        "application/x-kexiproject-shortcut",
+        "application/x-kexi-connectiondata"});
+    m_srcConnSel->setExcludedMimeTypes(excludedMimeTypes);
 
     vbox->addWidget(m_srcConnSel);
 
@@ -312,6 +312,7 @@ void ImportTableWizard::setupFinishPage()
     vbox->addWidget(m_finishLbl);
     m_finishCheckBox = new QCheckBox(xi18n("Open imported table"),
                                      m_finishPageWidget);
+    m_finishCheckBox->setChecked(true);
     vbox->addSpacing(KexiUtils::spacingHint());
     vbox->addWidget(m_finishCheckBox);
     vbox->addStretch(1);
@@ -346,7 +347,6 @@ void ImportTableWizard::slot_currentPageChanged(KPageWidgetItem* curPage,KPageWi
 
 void ImportTableWizard::arriveSrcConnPage()
 {
-    qDebug();
 }
 
 void ImportTableWizard::arriveSrcDBPage()
@@ -391,6 +391,12 @@ void ImportTableWizard::arriveTableSelectPage(KPageWidgetItem *prevPage)
 
         bool ok = m_migrateDriver;
         if (ok) {
+            if (!m_sourceDbEncoding.isEmpty()) {
+                m_migrateDriver->setPropertyValue(
+                    "source_database_nonunicode_encoding",
+                    QVariant(m_sourceDbEncoding.toUpper().remove(' ')) // "CP1250", not "cp 1250"
+                    );
+            }
             ok = m_migrateDriver->connectSource(&result);
         }
         if (ok) {
@@ -452,7 +458,7 @@ void ImportTableWizard::arriveAlterTablePage()
 
 bool ImportTableWizard::readFromTable()
 {
-    QScopedPointer<KDbSqlResult> tableResult(m_migrateDriver->readFromTable(m_importTableName));
+    QSharedPointer<KDbSqlResult> tableResult = m_migrateDriver->readFromTable(m_importTableName);
     KDbTableSchema *newSchema = m_alterSchemaWidget->newSchema();
     if (!tableResult || tableResult->lastResult().isError()
             || tableResult->fieldsCount() != newSchema->fieldCount())
@@ -465,7 +471,7 @@ bool ImportTableWizard::readFromTable()
     }
     QScopedPointer<QList<KDbRecordData*>> data(new QList<KDbRecordData*>);
     for (int i = 0; i < RECORDS_FOR_PREVIEW; ++i) {
-        QScopedPointer<KDbRecordData> record(tableResult->fetchRecordData());
+        QSharedPointer<KDbRecordData> record(tableResult->fetchRecordData());
         if (!record) {
             if (tableResult->lastResult().isError()) {
                 return false;
@@ -509,7 +515,7 @@ void ImportTableWizard::arriveImportingPage()
     m_lblImportingTxt->setText(txt);
 
     //temp. hack for MS Access driver only
-    //! @todo for other databases we will need KexiMigration::Conenction
+    //! @todo for other databases we will need KexiMigration::Connection
     //! and KexiMigration::Driver classes
     bool showOptions = false;
     if (fileBasedSrcSelected()) {
@@ -518,9 +524,7 @@ void ImportTableWizard::arriveImportingPage()
         if (sourceDriver) {
             showOptions = !result.error()
             && sourceDriver->propertyValue("source_database_has_nonunicode_encoding").toBool();
-            KexiMigration::Data *data = sourceDriver->data();
-            sourceDriver->setData(0);
-            delete data;
+            sourceDriver->setData(nullptr);
         }
     }
     if (showOptions)
@@ -529,6 +533,7 @@ void ImportTableWizard::arriveImportingPage()
         m_importOptionsButton->hide();
 
     m_importingPageWidget->show();
+    setAppropriate(m_progressPageItem, true);
 }
 
 void ImportTableWizard::arriveProgressPage()
@@ -554,16 +559,20 @@ void ImportTableWizard::arriveProgressPage()
 void ImportTableWizard::arriveFinishPage()
 {
     if (m_importComplete) {
+        m_finishPageItem->setHeader(xi18n("Success"));
         m_finishLbl->setText(xi18nc("@info",
                                     "Table <resource>%1</resource> has been imported.",
                                     m_alterSchemaWidget->nameWidget()->nameText()));
     } else {
-        m_finishCheckBox->setEnabled(false);
-        m_finishLbl->setText(xi18n("An error occured."));
+        m_finishPageItem->setHeader(xi18n("Failure"));
+        m_finishLbl->setText(xi18n("An error occurred."));
     }
     m_migrateDriver->disconnectSource();
-
-    button(QDialogButtonBox::Cancel)->setEnabled(false);
+    button(QDialogButtonBox::Cancel)->setEnabled(!m_importComplete);
+    m_finishCheckBox->setVisible(m_importComplete);
+    finishButton()->setEnabled(m_importComplete);
+    nextButton()->setEnabled(m_importComplete);
+    setAppropriate(m_progressPageItem, false);
 }
 
 bool ImportTableWizard::fileBasedSrcSelected() const
@@ -573,6 +582,7 @@ bool ImportTableWizard::fileBasedSrcSelected() const
 
 KexiMigrate* ImportTableWizard::prepareImport(Kexi::ObjectStatus *result)
 {
+    Q_ASSERT(result);
     // Find a source (migration) driver name
     QString sourceDriverId = driverIdForSelectedSource();
     if (sourceDriverId.isEmpty()) {
@@ -623,7 +633,7 @@ KexiMigrate* ImportTableWizard::prepareImport(Kexi::ObjectStatus *result)
 
         if (fileBasedSrcSelected()) {
             KDbConnectionData* conn_data = new KDbConnectionData();
-            conn_data->setDatabaseName(m_srcConnSel->selectedFileName());
+            conn_data->setDatabaseName(m_srcConnSel->selectedFile());
             md->source = conn_data;
             md->sourceName.clear();
         } else {
@@ -632,7 +642,7 @@ KexiMigrate* ImportTableWizard::prepareImport(Kexi::ObjectStatus *result)
 
         }
 
-        md->keepData = keepData;
+        md->setShouldCopyData(keepData);
         sourceDriver->setData(md);
 
         return sourceDriver;
@@ -646,13 +656,14 @@ QString ImportTableWizard::driverIdForSelectedSource()
 {
     if (fileBasedSrcSelected()) {
         QMimeDatabase db;
-        QMimeType mime = db.mimeTypeForFile(m_srcConnSel->selectedFileName());
+        QMimeType mime = db.mimeTypeForFile(m_srcConnSel->selectedFile());
         if (!mime.isValid()
             || mime.name() == "application/octet-stream"
-            || mime.name() == "text/plain")
+            || mime.name() == "text/plain"
+            || mime.name() == "application/zip")
         {
             //try by URL:
-            mime = db.mimeTypeForFile(m_srcConnSel->selectedFileName());
+            mime = db.mimeTypeForFile(m_srcConnSel->selectedFile());
         }
         if (!mime.isValid()) {
             return QString();
@@ -696,7 +707,9 @@ bool ImportTableWizard::doImport()
     }
 
     //Create the table
-    if (!m_connection->createTable(newSchema, true)) {
+    if (!m_connection->createTable(newSchema,
+            KDbConnection::CreateTableOption::Default | KDbConnection::CreateTableOption::DropDestination))
+    {
         msg.showErrorMessage(KDbMessageHandler::Error,
                              xi18nc("@info", "Unable to create table <resource>%1</resource>.",
                                     newSchema->name()));
@@ -743,6 +756,9 @@ bool ImportTableWizard::doImport()
 void ImportTableWizard::slotConnPageItemSelected(bool isSelected)
 {
     setValid(m_srcConnPageItem, isSelected);
+    if (isSelected && fileBasedSrcSelected()) {
+        next();
+    }
 }
 
 void ImportTableWizard::slotTableListWidgetSelectionChanged()
@@ -759,3 +775,11 @@ void ImportTableWizard::slotCancelClicked()
 {
     m_importWasCanceled = true;
 }
+
+void ImportTableWizard::slotOptionsButtonClicked()
+{
+    OptionsDialog dlg(m_srcConnSel->selectedFile(), m_sourceDbEncoding, this);
+    if (QDialog::Accepted == dlg.exec()) {
+        m_sourceDbEncoding = dlg.encodingComboBox()->selectedEncoding();
+    }
+}
