@@ -266,9 +266,7 @@ public:
     virtual bool eventFilter(QObject *o, QEvent *e);
 
 public Q_SLOTS:
-    virtual void setData(KDbTableViewData *data, bool owner = true) {
-        KexiDataAwareObjectInterface::setData(data, owner);
-    }
+    void setData(KDbTableViewData *data, bool owner = true);
 
     virtual void clearColumnsInternal(bool repaint);
 
@@ -518,13 +516,13 @@ protected:
     virtual void clearVariables();
 
     /*! Implementation for KexiDataAwareObjectInterface */
-    virtual Qt::SortOrder currentLocalSortOrder() const;
+    virtual KDbOrderByColumn::SortOrder currentLocalSortOrder() const;
 
     /*! Implementation for KexiDataAwareObjectInterface */
     virtual int currentLocalSortColumn() const;
 
     /*! Implementation for KexiDataAwareObjectInterface */
-    virtual void setLocalSortOrder(int column, Qt::SortOrder order);
+    virtual void setLocalSortOrder(int column, KDbOrderByColumn::SortOrder order);
 
     /*! Implementation for KexiDataAwareObjectInterface */
     virtual void updateGUIAfterSorting(int previousRow);
@@ -644,7 +642,7 @@ protected:
 
     /*! Sets \a cellValue if there is a lookup value for the cell \a data.
      Used in paintCell() and KexiTableCellToolTip::maybeTip()
-     \return true is \a cellValue has been found. */
+     \return true if \a cellValue has been found. */
     bool getVisibleLookupValue(QVariant& cellValue, KexiTableEdit *edit,
                                KDbRecordData *data, KDbTableViewColumn *tvcol) const;
 
